@@ -582,6 +582,8 @@ enum algos {
         ALGO_ANIME,
         ALGO_ARGON2D250,
         ALGO_ARGON2D500,
+        ALGO_ARGON2D1000,
+        ALGO_ARGON2D16000,
         ALGO_ARGON2D4096,
         ALGO_AXIOM,       
         ALGO_BLAKE,       
@@ -677,6 +679,8 @@ static const char* const algo_names[] = {
         "anime",
         "argon2d250",
         "argon2d500",
+        "argon2d1000",
+        "argon2d16000",
         "argon2d4096",
         "axiom",
         "blake",
@@ -837,6 +841,8 @@ Options:\n\
                           anime         Animecoin (ANI)\n\
                           argon2d250\n\
                           argon2d500\n\
+                          argon2d1000\n\
+                          argon2d16000\n\
                           argon2d4096\n\
                           axiom         Shabal-256 MemoHash\n\
                           blake         blake256r14 (SFR)\n\
